@@ -6,3 +6,10 @@ from .client import KustoClient
 from .client_request_properties import ClientRequestProperties
 from .kcsb import KustoConnectionStringBuilder
 from .data_format import DataFormat
+
+__all__ = [
+    "KustoClient",
+    "ClientRequestProperties",
+    "KustoConnectionStringBuilder",
+    "DataFormat",
+]
