@@ -28,8 +28,8 @@ class DataFormat(Enum):
     JSON = ("json", IngestionMappingKind.JSON, True)
     SINGLEJSON = ("singlejson", IngestionMappingKind.JSON, True)
     MULTIJSON = ("multijson", IngestionMappingKind.JSON, True)
-    AVRO = ("avro", IngestionMappingKind.AVRO, True)
-    APACHEAVRO = ("apacheavro", IngestionMappingKind.APACHEAVRO, True)
+    AVRO = ("avro", IngestionMappingKind.AVRO, False)
+    APACHEAVRO = ("apacheavro", IngestionMappingKind.APACHEAVRO, False)
     PARQUET = ("parquet", IngestionMappingKind.PARQUET, False)
     SSTREAM = ("sstream", IngestionMappingKind.SSTREAM, False)
     ORC = ("orc", IngestionMappingKind.ORC, False)
