@@ -10,6 +10,7 @@ import platform
 import random
 from datetime import datetime
 from typing import Optional, ClassVar, Callable
+from urllib.parse import urljoin
 
 import pytest
 from azure.identity import DefaultAzureCredential
@@ -336,6 +337,7 @@ class TestE2E:
         assert cloud_info is not CloudSettings.DEFAULT_CLOUD
         assert cloud_info == CloudSettings.DEFAULT_CLOUD
         assert cloud_info is CloudSettings.get_cloud_info_for_cluster(self.engine_cs)
+        assert cloud_info == CloudSettings.get_cloud_info_for_cluster(urljoin(self.engine_cs, "/test1/test2/test3"))
 
     def test_cloud_info_404(self):
         pytest.skip("This test is currently wrong - until all cluster are updated to the redirect uri, this test will fail")
@@ -345,6 +347,7 @@ class TestE2E:
 
     @pytest.mark.parametrize("code", [301, 302, 307, 308])
     def test_no_redirects_fail_in_cloud(self, code):
+        pytest.skip("This test is currently not supported as it relies on the URI path witch we now ignore")
         with KustoClient(
             KustoConnectionStringBuilder.with_azure_token_credential(f"https://statusreturner.azurewebsites.net/{code}/nocloud", self.__class__.cred())
         ) as client:
@@ -365,6 +368,7 @@ class TestE2E:
     @pytest.mark.asyncio
     @pytest.mark.parametrize("code", [301, 302, 307, 308])
     async def test_no_redirects_fail_in_cloud_async(self, code):
+        pytest.skip("This test is currently not supported as it relies on the URI path witch we now ignore")
         async with AsyncKustoClient(
             KustoConnectionStringBuilder.with_azure_token_credential(f"https://statusreturner.azurewebsites.net/{code}/nocloud", self.__class__.async_cred())
         ) as client:
@@ -382,3 +386,16 @@ class TestE2E:
             with pytest.raises(KustoServiceError) as ex:
                 await client.execute("db", "table")
             assert ex.value.http_response.status == code
+
+    def test_semantic_error(self):
+        with self.get_client() as client:
+            with pytest.raises(KustoServiceError) as ex:
+                client.execute(self.test_db, "Nonexistent")
+            assert ex.value.is_semantic_error()
+
+    @pytest.mark.asyncio
+    async def test_semantic_error_async(self):
+        async with await self.get_async_client() as client:
+            with pytest.raises(KustoServiceError) as ex:
+                await client.execute(self.test_db, "Nonexistent")
+            assert ex.value.is_semantic_error()
