@@ -127,7 +127,6 @@ class ColumnMapping:
             results.append(f"{kind} needs at least one of the required properties: {needed_props}")
 
         if self.properties.get(self.TRANSFORMATION_METHOD):
-
             if (self.properties.get(self.PATH) or self.properties.get(self.FIELD_NAME)) and self.properties.get(
                 self.TRANSFORMATION_METHOD
             ) in self.CONSTANT_TRANSFORMATION_METHODS:
@@ -153,6 +152,9 @@ class IngestionProperties:
     For more information check out https://docs.microsoft.com/en-us/azure/data-explorer/ingestion-properties
     """
 
+    _DATABASE = "database"
+    _TABLE = "table"
+
     def __init__(
         self,
         database: str,
@@ -172,7 +174,6 @@ class IngestionProperties:
         validation_policy: Optional[ValidationPolicy] = None,
         additional_properties: Optional[dict] = None,
     ):
-
         if ingestion_mapping_reference is None and column_mappings is None:
             if ingestion_mapping_kind is not None:
                 raise KustoMissingMappingError(f"When ingestion mapping kind is set ('{ingestion_mapping_kind.value}'), a mapping must be provided.")
@@ -217,3 +218,7 @@ class IngestionProperties:
         self.report_method = report_method
         self.validation_policy = validation_policy
         self.additional_properties = additional_properties
+
+    def get_tracing_attributes(self) -> dict:
+        """Gets dictionary of attributes to be documented during tracing"""
+        return {self._DATABASE: self.database, self._TABLE: self.table}
