@@ -3,15 +3,15 @@ import json
 import os
 import uuid
 from tempfile import NamedTemporaryFile
+from unittest.mock import patch
 
 import pytest
 import responses
-from mock import patch
 
 from azure.kusto.data.data_format import DataFormat
 from azure.kusto.data.exceptions import KustoApiError
 from azure.kusto.ingest import ManagedStreamingIngestClient, IngestionProperties, IngestionStatus, BlobDescriptor
-from test_kusto_ingest_client import request_callback as queued_request_callback, assert_queued_upload
+from test_kusto_ingest_client import request_callback as queued_request_callback, assert_queued_upload, request_callback_throw_transient
 from test_kusto_streaming_ingest_client import request_callback as streaming_request_callback, assert_managed_streaming_request_id
 
 
@@ -21,6 +21,11 @@ class TransientResponseHelper:
         self.total_calls = 0
 
 
+@pytest.fixture(params=["Blob", "File"])
+def is_blob(request):
+    return request.param == "Blob"
+
+
 def transient_error_callback(helper: TransientResponseHelper, request, custom_request_id=None):
     if custom_request_id:
         assert request.headers["x-ms-client-request-id"] == custom_request_id
@@ -84,7 +89,7 @@ class TestManagedStreamingIngestClient:
     @patch("azure.storage.blob.BlobClient.upload_blob")
     @patch("azure.storage.queue.QueueClient.send_message")
     @patch("uuid.uuid4", return_value=MOCKED_UUID_4)
-    def test_fallback_big_file(self, mock_uuid, mock_put_message_in_queue, mock_upload_blob_from_stream, mock_aad):
+    def test_fallback_big_file(self, mock_uuid, mock_put_message_in_queue, mock_upload_blob_from_stream, mock_aad, is_blob):
         responses.add_callback(
             responses.POST, "https://ingest-somecluster.kusto.windows.net/v1/rest/mgmt", callback=queued_request_callback, content_type="application/json"
         )
@@ -96,7 +101,7 @@ class TestManagedStreamingIngestClient:
         )
 
         data_format = DataFormat.ORC  # Using orc to avoid compression
-        ingest_client = ManagedStreamingIngestClient.from_dm_kcsb("https://ingest-somecluster.kusto.windows.net")
+        ingest_client = ManagedStreamingIngestClient("https://ingest-somecluster.kusto.windows.net")
         ingestion_properties = IngestionProperties(database="database", table="table", data_format=data_format)
 
         initial_bytes = bytearray(os.urandom(5 * 1024 * 1024))
@@ -108,10 +113,20 @@ class TestManagedStreamingIngestClient:
         mock_upload_blob_from_stream.side_effect = check_bytes
 
         f = NamedTemporaryFile(dir=".", mode="wb", delete=False)
+        blob_url = "https://storageaccount.blob.core.windows.net/tempstorage/database__table__11111111-1111-1111-1111-111111111111__{}?".format(
+            os.path.basename(f.name)
+        )
+
         try:
-            f.write(initial_bytes)
-            f.close()
-            result = ingest_client.ingest_from_file(f.name, ingestion_properties=ingestion_properties)
+            if is_blob:
+                result = ingest_client.ingest_from_blob(BlobDescriptor(blob_url + "sas", 5 * 1024 * 1024), ingestion_properties=ingestion_properties)
+                f.close()
+            else:
+                f.write(initial_bytes)
+                f.close()
+                result = ingest_client.ingest_from_file(f.name, ingestion_properties=ingestion_properties)
+        except Exception as e:
+            print(e)
         finally:
             os.unlink(f.name)
 
@@ -119,14 +134,13 @@ class TestManagedStreamingIngestClient:
 
         assert_queued_upload(
             mock_put_message_in_queue,
-            mock_upload_blob_from_stream,
-            "https://storageaccount.blob.core.windows.net/tempstorage/database__table__11111111-1111-1111-1111-111111111111__{}?".format(
-                os.path.basename(f.name)
-            ),
+            mock_upload_blob_from_stream if not is_blob else None,
+            blob_url,
             format=data_format.kusto_value,
         )
 
-        mock_upload_blob_from_stream.assert_called()
+        if not is_blob:
+            mock_upload_blob_from_stream.assert_called()
 
     @responses.activate
     @patch("azure.kusto.data.security._AadHelper.acquire_authorization_header", return_value=None)
@@ -145,7 +159,7 @@ class TestManagedStreamingIngestClient:
         )
 
         data_format = DataFormat.ORC  # Using orc to avoid compression
-        ingest_client = ManagedStreamingIngestClient.from_engine_kcsb("https://somecluster.kusto.windows.net")
+        ingest_client = ManagedStreamingIngestClient("https://somecluster.kusto.windows.net")
         ingestion_properties = IngestionProperties(database="database", table="table", data_format=data_format)
 
         initial_bytes = bytearray(os.urandom(5 * 1024 * 1024))
@@ -183,7 +197,7 @@ class TestManagedStreamingIngestClient:
             responses.POST, "https://ingest-somecluster.kusto.windows.net/v1/rest/mgmt", callback=queued_request_callback, content_type="application/json"
         )
 
-        ingest_client = ManagedStreamingIngestClient.from_engine_kcsb("https://somecluster.kusto.windows.net")
+        ingest_client = ManagedStreamingIngestClient("https://somecluster.kusto.windows.net")
         ingest_client._set_retry_settings(0)
         ingestion_properties = IngestionProperties(database="database", table="table")
 
@@ -236,7 +250,7 @@ class TestManagedStreamingIngestClient:
             content_type="application/json",
         )
 
-        ingest_client = ManagedStreamingIngestClient.from_engine_kcsb("https://somecluster.kusto.windows.net")
+        ingest_client = ManagedStreamingIngestClient("https://somecluster.kusto.windows.net")
         ingest_client._set_retry_settings(0)
         ingestion_properties = IngestionProperties(database="database", table="table")
 
@@ -290,7 +304,7 @@ class TestManagedStreamingIngestClient:
             content_type="application/json",
         )
 
-        ingest_client = ManagedStreamingIngestClient.from_dm_kcsb("https://ingest-somecluster.kusto.windows.net")
+        ingest_client = ManagedStreamingIngestClient("https://ingest-somecluster.kusto.windows.net")
         ingestion_properties = IngestionProperties(database="database", table="table", data_format=DataFormat.CSV)
 
         current_dir = os.getcwd()
@@ -314,8 +328,14 @@ class TestManagedStreamingIngestClient:
         responses.add_callback(
             responses.POST, "https://ingest-somecluster.kusto.windows.net/v1/rest/mgmt", callback=queued_request_callback, content_type="application/json"
         )
+        responses.add_callback(
+            responses.POST,
+            "https://somecluster.kusto.windows.net/v1/rest/ingest/database/table?streamFormat=csv&sourceKind=uri",
+            callback=request_callback_throw_transient,
+            content_type="application/json",
+        )
 
-        ingest_client = ManagedStreamingIngestClient.from_dm_kcsb("https://ingest-somecluster.kusto.windows.net")
+        ingest_client = ManagedStreamingIngestClient("https://ingest-somecluster.kusto.windows.net")
         ingestion_properties = IngestionProperties(database="database", table="table")
 
         blob_path = (
@@ -331,3 +351,45 @@ class TestManagedStreamingIngestClient:
             mock_upload_blob_from_stream=None,
             expected_url="https://storageaccount.blob.core.windows.net/tempstorage/database__table__11111111-1111-1111-1111-111111111111__tmpbvk40leg?",
         )
+
+    def test_client_uri_from_query_endpoint(self):
+        client = ManagedStreamingIngestClient("https://somecluster.kusto.windows.net")
+        assert (
+            client.queued_client._connection_datasource == "https://ingest-somecluster.kusto.windows.net"
+        ), "Client URI was not extracted correctly from query endpoint"
+
+        assert client.queued_client._resource_manager._kusto_client._kusto_cluster == "https://ingest-somecluster.kusto.windows.net/"
+
+        assert (
+            client.streaming_client._kusto_client._kusto_cluster == "https://somecluster.kusto.windows.net/"
+        ), "Client URI was not extracted correctly from ingestion endpoint"
+
+    def test_client_uri_from_ingestion_endpoint(self):
+        client = ManagedStreamingIngestClient("https://ingest-somecluster.kusto.windows.net")
+        assert (
+            client.queued_client._connection_datasource == "https://ingest-somecluster.kusto.windows.net"
+        ), "Client URI was not extracted correctly from query endpoint"
+
+        assert client.queued_client._resource_manager._kusto_client._kusto_cluster == "https://ingest-somecluster.kusto.windows.net/"
+
+        assert (
+            client.streaming_client._kusto_client._kusto_cluster == "https://somecluster.kusto.windows.net/"
+        ), "Client URI was not extracted correctly from ingestion endpoint"
+
+    def test_from_ingestion_endpoint_reserved_hostname(self):
+        client = ManagedStreamingIngestClient("https://localhost:8080")
+        assert client.queued_client._connection_datasource == "https://localhost:8080", "Client URI was not extracted correctly from query endpoint"
+        assert client.queued_client._resource_manager._kusto_client._kusto_cluster == "https://localhost:8080/"
+        assert client.streaming_client._kusto_client._kusto_cluster == "https://localhost:8080/"
+
+        client = ManagedStreamingIngestClient("https://192.168.14.4")
+        assert client.queued_client._connection_datasource == "https://192.168.14.4", "Client URI was not extracted correctly from query endpoint"
+        assert client.queued_client._resource_manager._kusto_client._kusto_cluster == "https://192.168.14.4/"
+        assert client.streaming_client._kusto_client._kusto_cluster == "https://192.168.14.4/"
+
+        client = ManagedStreamingIngestClient("https://onebox.dev.kusto.windows.net")
+        assert (
+            client.queued_client._connection_datasource == "https://onebox.dev.kusto.windows.net"
+        ), "Client URI was not extracted correctly from query endpoint"
+        assert client.queued_client._resource_manager._kusto_client._kusto_cluster == "https://onebox.dev.kusto.windows.net/"
+        assert client.streaming_client._kusto_client._kusto_cluster == "https://onebox.dev.kusto.windows.net/"
